@@ -33,6 +33,10 @@ class Resource(IResource, metaclass=ResourceMetaclass):
     def get_list_url(cls, *params: Any) -> str:
         return cls._meta.get_list_url()
 
+    @classmethod
+    def get_retrieve_url(cls: type[T], resource_id: int | str | None) -> str:
+        return cls._meta.get_retrieve_url(resource_id)
+
     @classmethod
     def get_next_url(
         cls,
@@ -44,7 +48,7 @@ class Resource(IResource, metaclass=ResourceMetaclass):
         raise NotImplementedError
 
     @classmethod
-    def process_response(cls, action: str, data: dict[str, Any]) -> dict[str, Any]:
+    def process_response(cls, action: str | None, data: dict[str, Any]) -> dict[str, Any]:
         """Process response data prior to parsing using the declared model."""
         return data
 
